@@ -36,6 +36,26 @@ def get_response(code, body):
             "body": body
         }
 
+def get_debug_msg(*args):
+    msg = "*** debug ***\n"
+    for i in args:
+        msg += str(i) + ", "
+    msg = msg[:-2]
+    msg += "\n*************"
+    print(font_formatter("italic", (font_formatter("white", msg))))
+
+def font_formatter(n, s):
+    # https://stackoverflow.com/questions/287871/how-to-print-colored-text-in-python/50025330
+
+    code = {
+        "green": 92,
+        "red": 91,
+        "italic": 3,
+        "white": 37,
+        "blue": 34
+    }
+    value = "\033[" + str(code[n]) + "m" + s + "\033[0m"
+    return value
 
 def get_config():
     with open(os.path.dirname(__file__) + "/../config.json", "r") as read_file:
@@ -286,21 +306,22 @@ def make_update_string(object, table, key, key_value):
     return update_string
 
 
-def make_update_string_v2(object, table, key, key_value):
+def make_update_string_v2(payload, table, key, key_value):
     string = ""
 
-    for name, value in object.items():
+    for name, value in payload.items():
         if name != key:
             if type(value) == str:
                 value = value.replace("'", "''")
 
             if type(value) == dict:
-                if value == {} or value == "":
+                if not value:
                     string = string + name + " = '{}', "
                 else:
                     string = string + name + " = '" + json.dumps(value) + "', "
 
             elif type(value) is list:
+                value = [item.replace("'", "''") for item in value]
 
                 if is_list_of_jsons(value) is True and value != []:
                     value = json.dumps(value).replace("[", "{'").replace("]", "'}")
@@ -311,7 +332,6 @@ def make_update_string_v2(object, table, key, key_value):
                     string = string + name + " = '" + value + "', "
 
             elif type(value) is bool:
-
                 string += name + " = " + str(value) + ", "
 
             elif value is None:
